InductiveNodePiece
==================

.. currentmodule:: pykeen.models

.. autoclass:: InductiveNodePiece
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InductiveNodePiece.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~InductiveNodePiece.create_entity_representation_for_new_triples

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: create_entity_representation_for_new_triples
